==> landers.angular-2.0.77.tgz: package/src/control/directive-list-status.js <==
;angular.module('Landers.angular')
    .directive('listStatus', ['$templateRequest', '$compile', 'Flat', 'Helpers', '$timeout', function($templateRequest, $compile, Flat, Helpers, $timeout){
        return {
            restrict : 'A',
            link : function($scope, $ele, $attrs){
                $ele.addClass('list-status');
                var myScope = Helpers.seekScope($scope, $attrs['useScope']);

                var modelKey = $attrs['modelKey'], html = '';
                var datakey1 = [modelKey, '$list', 'data'].join('.');
                var icon1 = '<i class="glyphicon glyphicon-info-sign"></i> ';
                var icon2 = '<i class="glyphicon glyphicon-remove-sign"></i>';

                myScope.$watch(datakey1, function(newValue){
                    var html;
                    if (newValue) {
                        if ( !newValue.length ) {
                            var datakey2 = [modelKey, '$errors.$list'].join('.');
                            var error_message = Flat.get(myScope, datakey2);
                            if ( !error_message ) {
                                datakey3 = [modelKey, '$search'].join('.');
                                var htmlTpl = '<div class="alert alert-warning pv20">%s</div>';
                                var datakey4 = [modelKey, '$name'].join('.');
                                var appname = Flat.get(myScope, datakey4);

                                var searchData = Flat.get(myScope, datakey3);
                                for (var k in searchData) {
                                    if ( searchData[k] === '' ) delete searchData[k];
                                }
                                if ( searchData && Landers.utils.json.count(searchData) ) {
                                    html = icon1 + ' 没有检索到符合条件的' + appname + '。您可以尝试其他搜索条件或<a class="highlight hand" ng-click="' + modelKey + '.$event.resetSearch()">重置搜索</a> ';
                                    html = Landers.utils.str.sprintf(htmlTpl, html);
                                } else {
                                    var partial = $attrs['partialNone'];
                                    var message = $attrs['messageNone'];
                                    if (partial) {
                                        var partial_url = myScope.$partial(partial);
                                        $templateRequest(partial_url).then(function(html){
                                            html = Landers.utils.str.sprintf(htmlTpl, html);
                                            $ele.fadeOut(300, function(){
                                                $timeout(function(){//必须加延时，否则可能html未解析
                                                    $ele.html($compile(html)(myScope)).fadeIn(300);
                                                }, 100);
                                            });
                                        });
                                        return;

                                    } else if (message) {
                                        html = message;
                                    } else {
                                        html = '暂无' + appname + '。';
                                    }
                                    html = Landers.utils.str.sprintf(htmlTpl, icon1 + html);
                                }
                            } else {
                                html = '<div class="alert alert-danger pv20">' + icon2 + ' ' + error_message + ' </div>';
                            }
                            $ele.fadeOut(300, function(){
                                $ele.html($compile(html)(myScope)).fadeIn(300);
                            });
                        } else {
                            $ele.empty().stop(true).hide();
                        }
                    } else {
                        html = '<div class="alert alert-default pv20"><i class="glyphicon glyphicon-cog glyphicon-spin fa fa-cog fa-spin"></i> loading... </div>';
                        $ele.html($compile(html)(myScope)).hide().fadeIn(500);
                    }
                }, true);
            }
        };
    }]);

==> landers.angular-2.1.62.tgz: package/src/control/directive-list-status.js <==
;angular.module('Landers.angular')
    .directive('listStatus', ['$templateRequest', '$compile', 'Flat', 'Helpers', '$timeout', function($templateRequest, $compile, Flat, Helpers, $timeout){
        return {
            restrict : 'A',
            link : function($scope, $ele, $attrs){
                $ele.addClass('list-status');
                var myScope = Helpers.seekScope($scope, $attrs['useScope']);

                var modelKey = $attrs['modelKey'], html = '';
                var datakey1 = [modelKey, '$list', 'status'].join('.');
                var datakey2 = [modelKey, '$list', 'data'].join('.');
                var icon1 = '<i class="glyphicon glyphicon-info-sign"></i> ';
                var icon2 = '<i class="glyphicon glyphicon-remove-sign"></i>';
                myScope.$watch(datakey1, function(newValue){
                    switch(newValue) {
                        case 'LOADING':
                            var html = '<div class="alert alert-default pv20"><i class="glyphicon glyphicon-cog glyphicon-spin fa fa-cog fa-spin"></i> loading... </div>';
                            $ele.html($compile(html)(myScope)).hide().fadeIn(500);
                            break;
                        case 'COMPLETED':
                            $ele.empty();
                            break;
                    }

                });
                myScope.$watch(datakey2, function(newValue){
                    if (newValue) {
                        if ( !newValue.length ) {
                            var datakey2 = [modelKey, '$errors.$list'].join('.');
                            var error_message = Flat.get(myScope, datakey2);
                            if ( !error_message ) {
                                datakey3 = [modelKey, '$search'].join('.');
                                var htmlTpl = '<div class="alert alert-warning pv20">%s</div>';
                                var datakey4 = [modelKey, '$name'].join('.');
                                var appname = Flat.get(myScope, datakey4);

                                var searchData = Flat.get(myScope, datakey3);
                                for (var k in searchData) {
                                    if ( searchData[k] === '' ) delete searchData[k];
                                }

                                var html;
                                if ( searchData && Landers.utils.json.count(searchData) ) {
                                    html = icon1 + ' 没有检索到符合条件的' + appname + '。您可以尝试其他搜索条件或<a class="highlight hand" ng-click="' + modelKey + '.$event.resetSearch()">重置搜索</a> ';
                                    html = Landers.utils.str.sprintf(htmlTpl, html);
                                } else {
                                    var partial = $attrs['partialNone'];
                                    var message = $attrs['messageNone'];
                                    if (partial) {
                                        var partial_url = myScope.$partial(partial);
                                        $templateRequest(partial_url).then(function(html){
                                            html = Landers.utils.str.sprintf(htmlTpl, html);
                                            $ele.fadeOut(300, function(){
                                                $timeout(function(){//必须加延时，否则可能html未解析
                                                    $ele.html($compile(html)(myScope)).fadeIn(300);
                                                }, 100);
                                            });
                                        });
                                        return;

                                    } else if (message) {
                                        html = message;
                                    } else {
                                        html = '暂无' + appname + '。';
                                    }
                                    html = Landers.utils.str.sprintf(htmlTpl, icon1 + html);
                                }
                            } else {
                                html = '<div class="alert alert-danger pv20">' + icon2 + ' ' + error_message + ' </div>';
                            }
                            $ele.fadeOut(300, function(){
                                $ele.html($compile(html)(myScope)).fadeIn(300);
                            });
                        } else {
                            $ele.empty().stop(true).hide();
                        }
                    }
                }, true);
            }
        };
    }]);
